package org.netbeans.modules.cnd.dwarfdump;

import java.util.regex.*;

/**
 * Static methods for handling paths to files and directories.
 * Unlike the File class these methods handle both UNIX and Windows pathnames,
 * regardless of the system we are running on. 
 */
public class Paths {
	
	private static final Pattern winAbsPathPattern = Pattern.compile("^([a-zA-z]+:|\\\\\\\\)");
	private static final Pattern slashes = Pattern.compile("(/|\\\\)+");

	/**
	 * Tests whether a path is absolute.
	 * @param path The path.
	 * @return Whether the path is absolute.
	 */
	public static boolean isAbsolute(String path) {
		if (path.length() == 0) {
			return false;
		}
		// UNIX
		if (path.charAt(0) == '/') {
			return true;
		}
		// Windows
		return winAbsPathPattern.matcher(path).find();
	}
	
	/**
	 * Returns the name of the file or directory pointed to by a path.
	 * @param path The path
	 * @return The name of the file or directory.
	 */
	public static String getName(String path) {
		String[] components = slashes.split(path);
		int nameIndex = components.length - 1;
		return components[nameIndex];
	}
	
	/**
	 * Returns the name of the directory pointed to by a file of path.
	 * @param path The path
	 * @return The name of the directory.
	 */
	public static String getPath(String path) {
		String[] components = slashes.split(path);
		int nameIndex = components.length - 1;		
		return path.substring(0, path.length() - components[nameIndex].length());
	}	
}
